import { BundledLanguage, BundledTheme, createHighlighter } from 'shiki';

interface CreatePlainShikiOptions {
    /**
     * @description Language of the code to be highlighted.
     *
     * @requires
     */
    lang: BundledLanguage;
    /**
     * @description All languages to be imported.
     *
     * @default ["html","css","js"]
     */
    langs?: BundledLanguage[];
    /**
     * @description Theme of the code to be highlighted.
     *
     * @default {light:"min-light",dark:"min-dark"}
     */
    themes?: Record<string, BundledTheme>;
    /**
     * @description Root element selector corresponding to the theme.
     *
     * @default `.${theme}`
     */
    selector?: (theme: string) => string;
    /**
     * @description Whether to listen for element update events and automatic rendering.
     *
     * @default true
     */
    watch?: boolean;
    /**
     * @description Delay in updating when `watch: true`.
     *
     * @default 0
     */
    delay?: number;
    /**
     * @description Shiki highlighter instance.
     */
    instance?: Awaited<ReturnType<typeof createHighlighter>>;
}
declare function createPlainShiki(el: HTMLElement, options: CreatePlainShikiOptions): {
    readonly isSupported: boolean;
    dispose: () => void;
    update: () => void;
};

export { type CreatePlainShikiOptions, createPlainShiki };
